#! python3  # noqa: E265

"""Static objects and variables."""

VPC_FILE_NAME = "index.vpc"

VPC_SCHEMA: dict = {
    "$schema": "http://json-schema.org/draft-07/schema#",
    "$id": "https://stac-extensions.github.io/pointcloud/v1.0.0/schema.json#",
    "title": "Point Cloud Extension",
    "description": "STAC Point Cloud Extension for STAC Items and STAC Collections.",
    "oneOf": [
        {
            "$comment": "This is the schema for STAC Items.",
            "allOf": [
                {
                    "type": "object",
                    "required": ["type", "properties", "assets"],
                    "properties": {
                        "type": {"const": "Feature"},
                        "properties": {
                            "allOf": [
                                {
                                    "$comment": "Require fields here for item properties.",
                                    "required": [
                                        "pc:count",
                                        "pc:type",
                                        "pc:encoding",
                                        "pc:schemas",
                                    ],
                                },
                                {"$ref": "#/definitions/fields"},
                            ]
                        },
                        "assets": {
                            "type": "object",
                            "additionalProperties": {"$ref": "#/definitions/fields"},
                        },
                    },
                },
                {"$ref": "#/definitions/stac_extensions"},
            ],
        },
        {
            "$comment": "This is the schema for STAC Collections.",
            "allOf": [
                {
                    "type": "object",
                    "required": ["type"],
                    "properties": {
                        "type": {"const": "Collection"},
                        "assets": {
                            "type": "object",
                            "additionalProperties": {"$ref": "#/definitions/fields"},
                        },
                        "item_assets": {
                            "type": "object",
                            "additionalProperties": {"$ref": "#/definitions/fields"},
                        },
                    },
                },
                {
                    "$comment": "Remove this and the following object if this is not an extension to a Collection.",
                    "$ref": "#/definitions/stac_extensions",
                },
                {"$ref": "#/definitions/fields"},
            ],
        },
    ],
    "definitions": {
        "stac_extensions": {
            "type": "object",
            "required": ["stac_extensions"],
            "properties": {
                "stac_extensions": {
                    "type": "array",
                    "contains": {
                        "const": "https://stac-extensions.github.io/pointcloud/v1.0.0/schema.json"
                    },
                }
            },
        },
        "fields": {
            "type": "object",
            "properties": {
                "pc:count": {"type": "integer", "minimum": 0},
                "pc:type": {"type": "string"},
                "pc:encoding": {"type": "string"},
                "pc:schemas": {
                    "type": "array",
                    "minItems": 1,
                    "items": {"$ref": "#/definitions/schema"},
                },
                "pc:density": {"type": "number", "minimum": 0},
                "pc:statistics": {
                    "type": "array",
                    "minItems": 1,
                    "items": {"$ref": "#/definitions/stats"},
                },
            },
            "patternProperties": {"^(?!pc:)": {}},
            "additionalProperties": False,
        },
        "schema": {
            "type": "object",
            "required": ["name", "size", "type"],
            "properties": {
                "name": {"type": "string"},
                "size": {"type": "integer"},
                "type": {"type": "string", "enum": ["floating", "unsigned", "signed"]},
            },
        },
        "stats": {
            "type": "object",
            "minProperties": 2,
            "required": ["name"],
            "properties": {
                "name": {"type": "string"},
                "position": {"type": "integer"},
                "average": {"type": "number"},
                "count": {"type": "integer"},
                "maximum": {"type": "number"},
                "minimum": {"type": "number"},
                "stddev": {"type": "number"},
                "variance": {"type": "number"},
            },
        },
    },
}
